# MetaQ

The implementation of the paper "MetaQ: fast, scalable and accurate metacell inference via deep single-cell quantization". Please refer to the paper and code repository (https://github.com/XLearning-SCU/MetaQ) for more details.